# Variationist

Python package for Variationist: Exploring multifaceted variation and bias in written language data.

For more information, check our GitHub repository: https://github.com/dhfbk/variationist